EXPORTS
	?CancelReceiveBufferToBeEmptiedEvent@RMMFDevSoundProxy@@QAEXXZ @ 1 NONAME ; public: void __thiscall RMMFDevSoundProxy::CancelReceiveBufferToBeEmptiedEvent(void)
	?CancelReceiveBufferToBeFilledEvent@RMMFDevSoundProxy@@QAEXXZ @ 2 NONAME ; public: void __thiscall RMMFDevSoundProxy::CancelReceiveBufferToBeFilledEvent(void)
	?CancelReceiveInitializeCompleteEvent@RMMFDevSoundProxy@@QAEXXZ @ 3 NONAME ; public: void __thiscall RMMFDevSoundProxy::CancelReceiveInitializeCompleteEvent(void)
	?CancelReceivePlayErrorEvent@RMMFDevSoundProxy@@QAEXXZ @ 4 NONAME ; public: void __thiscall RMMFDevSoundProxy::CancelReceivePlayErrorEvent(void)
	?CancelReceiveToneFinishedEvent@RMMFDevSoundProxy@@QAEXXZ @ 5 NONAME ; public: void __thiscall RMMFDevSoundProxy::CancelReceiveToneFinishedEvent(void)
	?Capabilities@RMMFDevSoundProxy@@QAE?AVTMMFCapabilities@@XZ @ 6 NONAME ; public: class TMMFCapabilities  __thiscall RMMFDevSoundProxy::Capabilities(void)
	?Close@RMMFDevSoundProxy@@QAEXXZ @ 7 NONAME ; public: void __thiscall RMMFDevSoundProxy::Close(void)
	?Config@RMMFDevSoundProxy@@QAE?AVTMMFCapabilities@@XZ @ 8 NONAME ; public: class TMMFCapabilities  __thiscall RMMFDevSoundProxy::Config(void)
	?ConvertData@RMMFDevSoundProxy@@QAEXXZ @ 9 NONAME ; public: void __thiscall RMMFDevSoundProxy::ConvertData(void)
	?ConvertInitL@RMMFDevSoundProxy@@QAEXXZ @ 10 NONAME ; public: void __thiscall RMMFDevSoundProxy::ConvertInitL(void)
	?CustomInterface@RMMFDevSoundProxy@@QAEPAXVTUid@@@Z @ 11 NONAME ; public: void * __thiscall RMMFDevSoundProxy::CustomInterface(class TUid)
	?FixedSequenceCount@RMMFDevSoundProxy@@QAEHXZ @ 12 NONAME ; public: int __thiscall RMMFDevSoundProxy::FixedSequenceCount(void)
	?FixedSequenceName@RMMFDevSoundProxy@@QAEABVTDesC16@@H@Z @ 13 NONAME ; public: class TDesC16 const & __thiscall RMMFDevSoundProxy::FixedSequenceName(int)
	?Gain@RMMFDevSoundProxy@@QAEHXZ @ 14 NONAME ; public: int __thiscall RMMFDevSoundProxy::Gain(void)
	?GetPlayBalanceL@RMMFDevSoundProxy@@QAEXAAH0@Z @ 15 NONAME ; void RMMFDevSoundProxy::GetPlayBalanceL(int &, int &)
	?GetRecordBalanceL@RMMFDevSoundProxy@@QAEXAAH0@Z @ 16 NONAME ; void RMMFDevSoundProxy::GetRecordBalanceL(int &, int &)
	?GetRecordedBufferL@RMMFDevSoundProxy@@QAEHAAVCMMFDataBuffer@@@Z @ 17 NONAME ; public: int __thiscall RMMFDevSoundProxy::GetRecordedBufferL(class CMMFDataBuffer &)
	?GetSupportedInputDataTypesL@RMMFDevSoundProxy@@QAEXAAV?$RArray@VTFourCC@@@@ABVTMMFPrioritySettings@@@Z @ 18 NONAME ; public: void __thiscall RMMFDevSoundProxy::GetSupportedInputDataTypesL(class RArray<class TFourCC> &,class TMMFPrioritySettings const &)
	?GetSupportedOutputDataTypesL@RMMFDevSoundProxy@@QAEXAAV?$RArray@VTFourCC@@@@ABVTMMFPrioritySettings@@@Z @ 19 NONAME ; public: void __thiscall RMMFDevSoundProxy::GetSupportedOutputDataTypesL(class RArray<class TFourCC> &,class TMMFPrioritySettings const &)
	?InitializeL@RMMFDevSoundProxy@@QAEHV?$CArrayPtr@VTUid@@@@W4TMMFState@@@Z @ 20 NONAME ; public: int __thiscall RMMFDevSoundProxy::InitializeL(class CArrayPtr<class TUid>,enum TMMFState)
	?InitializeL@RMMFDevSoundProxy@@QAEHVTFourCC@@W4TMMFState@@@Z @ 21 NONAME ; public: int __thiscall RMMFDevSoundProxy::InitializeL(class TFourCC,enum TMMFState)
	?InitializeL@RMMFDevSoundProxy@@QAEHVTUid@@W4TMMFState@@@Z @ 22 NONAME ; public: int __thiscall RMMFDevSoundProxy::InitializeL(class TUid,enum TMMFState)
	?InitializeL@RMMFDevSoundProxy@@QAEHW4TMMFState@@@Z @ 23 NONAME ; public: int __thiscall RMMFDevSoundProxy::InitializeL(enum TMMFState)
	?MaxGain@RMMFDevSoundProxy@@QAEHXZ @ 24 NONAME ; public: int __thiscall RMMFDevSoundProxy::MaxGain(void)
	?MaxVolume@RMMFDevSoundProxy@@QAEHXZ @ 25 NONAME ; public: int __thiscall RMMFDevSoundProxy::MaxVolume(void)
	?Open@RMMFDevSoundProxy@@QAEHXZ @ 26 NONAME ; public: int __thiscall RMMFDevSoundProxy::Open(void)
	?Pause@RMMFDevSoundProxy@@QAEXXZ @ 27 NONAME ; public: void __thiscall RMMFDevSoundProxy::Pause(void)
	?PlayDTMFStringL@RMMFDevSoundProxy@@QAEXABVTDesC16@@@Z @ 28 NONAME ; public: void __thiscall RMMFDevSoundProxy::PlayDTMFStringL(class TDesC16 const &)
	?PlayData@RMMFDevSoundProxy@@QAEXXZ @ 29 NONAME ; public: void __thiscall RMMFDevSoundProxy::PlayData(void)
	?PlayDualToneL@RMMFDevSoundProxy@@QAEXHHABVTTimeIntervalMicroSeconds@@@Z @ 30 NONAME ; public: void __thiscall RMMFDevSoundProxy::PlayDualToneL(int,int,class TTimeIntervalMicroSeconds const &)
	?PlayFixedSequenceL@RMMFDevSoundProxy@@QAEXH@Z @ 31 NONAME ; public: void __thiscall RMMFDevSoundProxy::PlayFixedSequenceL(int)
	?PlayInitL@RMMFDevSoundProxy@@QAEXXZ @ 32 NONAME ; public: void __thiscall RMMFDevSoundProxy::PlayInitL(void)
	?PlayToneL@RMMFDevSoundProxy@@QAEXHABVTTimeIntervalMicroSeconds@@@Z @ 33 NONAME ; public: void __thiscall RMMFDevSoundProxy::PlayToneL(int,class TTimeIntervalMicroSeconds const &)
	?PlayToneSequenceL@RMMFDevSoundProxy@@QAEXABVTDesC8@@@Z @ 34 NONAME ; public: void __thiscall RMMFDevSoundProxy::PlayToneSequenceL(class TDesC8 const &)
	?ReceiveBufferToBeEmptiedEvent@RMMFDevSoundProxy@@QAEXAAV?$TPckgBuf@VTMMFDevSoundProxyHwBuf@@@@AAVTRequestStatus@@@Z @ 35 NONAME ; public: void __thiscall RMMFDevSoundProxy::ReceiveBufferToBeEmptiedEvent(class TPckgBuf<class TMMFDevSoundProxyHwBuf> &,class TRequestStatus &)
	?ReceiveBufferToBeFilledEvent@RMMFDevSoundProxy@@QAEXAAV?$TPckgBuf@VTMMFDevSoundProxyHwBuf@@@@AAVTRequestStatus@@@Z @ 36 NONAME ; public: void __thiscall RMMFDevSoundProxy::ReceiveBufferToBeFilledEvent(class TPckgBuf<class TMMFDevSoundProxyHwBuf> &,class TRequestStatus &)
	?ReceiveInitializeCompleteEvent@RMMFDevSoundProxy@@QAEXAAV?$TPckgBuf@VTMMFDevSoundProxyHwBuf@@@@AAVTRequestStatus@@@Z @ 37 NONAME ; public: void __thiscall RMMFDevSoundProxy::ReceiveInitializeCompleteEvent(class TPckgBuf<class TMMFDevSoundProxyHwBuf> &,class TRequestStatus &)
	?ReceivePlayErrorEvent@RMMFDevSoundProxy@@QAEXAAV?$TPckgBuf@VTMMFDevSoundProxyHwBuf@@@@AAVTRequestStatus@@@Z @ 38 NONAME ; public: void __thiscall RMMFDevSoundProxy::ReceivePlayErrorEvent(class TPckgBuf<class TMMFDevSoundProxyHwBuf> &,class TRequestStatus &)
	?ReceiveToneFinishedEvent@RMMFDevSoundProxy@@QAEXAAV?$TPckgBuf@VTMMFDevSoundProxyHwBuf@@@@AAVTRequestStatus@@@Z @ 39 NONAME ; public: void __thiscall RMMFDevSoundProxy::ReceiveToneFinishedEvent(class TPckgBuf<class TMMFDevSoundProxyHwBuf> &,class TRequestStatus &)
	?RecordData@RMMFDevSoundProxy@@QAEXXZ @ 40 NONAME ; public: void __thiscall RMMFDevSoundProxy::RecordData(void)
	?RecordInitL@RMMFDevSoundProxy@@QAEXXZ @ 41 NONAME ; public: void __thiscall RMMFDevSoundProxy::RecordInitL(void)
	?SamplesPlayed@RMMFDevSoundProxy@@QAEHXZ @ 42 NONAME ; public: int __thiscall RMMFDevSoundProxy::SamplesPlayed(void)
	?SamplesRecorded@RMMFDevSoundProxy@@QAEHXZ @ 43 NONAME ; public: int __thiscall RMMFDevSoundProxy::SamplesRecorded(void)
	?SetBuffer@RMMFDevSoundProxy@@QAEXPAVCMMFDataBuffer@@@Z @ 44 NONAME ; public: void __thiscall RMMFDevSoundProxy::SetBuffer(class CMMFDataBuffer *)
	?SetConfigL@RMMFDevSoundProxy@@QAEHABVTMMFCapabilities@@@Z @ 45 NONAME ; public: int __thiscall RMMFDevSoundProxy::SetConfigL(class TMMFCapabilities const &)
	?SetDTMFLengths@RMMFDevSoundProxy@@QAEXAAVTTimeIntervalMicroSeconds32@@00@Z @ 46 NONAME ; public: void __thiscall RMMFDevSoundProxy::SetDTMFLengths(class TTimeIntervalMicroSeconds32 &,class TTimeIntervalMicroSeconds32 &,class TTimeIntervalMicroSeconds32 &)
	?SetDevSoundInfo@RMMFDevSoundProxy@@QAEHXZ @ 47 NONAME ; public: int __thiscall RMMFDevSoundProxy::SetDevSoundInfo(void)
	?SetGain@RMMFDevSoundProxy@@QAEHH@Z @ 48 NONAME ; public: int __thiscall RMMFDevSoundProxy::SetGain(int)
	?SetPlayBalanceL@RMMFDevSoundProxy@@QAEXHH@Z @ 49 NONAME ; void RMMFDevSoundProxy::SetPlayBalanceL(int, int)
	?SetPrioritySettings@RMMFDevSoundProxy@@QAEXABVTMMFPrioritySettings@@@Z @ 50 NONAME ; public: void __thiscall RMMFDevSoundProxy::SetPrioritySettings(class TMMFPrioritySettings const &)
	?SetRecordBalanceL@RMMFDevSoundProxy@@QAEXHH@Z @ 51 NONAME ; public: void __thiscall RMMFDevSoundProxy::SetRecordBalanceL(int,int)
	?SetToneRepeats@RMMFDevSoundProxy@@QAEXHABVTTimeIntervalMicroSeconds@@@Z @ 52 NONAME ; public: void __thiscall RMMFDevSoundProxy::SetToneRepeats(int,class TTimeIntervalMicroSeconds const &)
	?SetVolume@RMMFDevSoundProxy@@QAEHH@Z @ 53 NONAME ; public: int __thiscall RMMFDevSoundProxy::SetVolume(int)
	?SetVolumeRamp@RMMFDevSoundProxy@@QAEXABVTTimeIntervalMicroSeconds@@@Z @ 54 NONAME ; public: void __thiscall RMMFDevSoundProxy::SetVolumeRamp(class TTimeIntervalMicroSeconds const &)
	?Stop@RMMFDevSoundProxy@@QAEXXZ @ 55 NONAME ; public: void __thiscall RMMFDevSoundProxy::Stop(void)
	?Volume@RMMFDevSoundProxy@@QAEHXZ @ 56 NONAME ; public: int __thiscall RMMFDevSoundProxy::Volume(void)
	?CancelReceiveRecordErrorEvent@RMMFDevSoundProxy@@QAEXXZ @ 57 NONAME ; public: void __thiscall RMMFDevSoundProxy::CancelReceiveRecordErrorEvent(void)
	?ReceiveRecordErrorEvent@RMMFDevSoundProxy@@QAEXAAV?$TPckgBuf@VTMMFDevSoundProxyHwBuf@@@@AAVTRequestStatus@@@Z @ 58 NONAME ; public: void __thiscall RMMFDevSoundProxy::ReceiveRecordErrorEvent(class TPckgBuf<class TMMFDevSoundProxyHwBuf> &,class TRequestStatus &)
	?CancelReceiveSendEventToClientEvent@RMMFDevSoundProxy@@QAEXXZ @ 59 NONAME ; public: void __thiscall RMMFDevSoundProxy::CancelReceiveSendEventToClientEvent(void)
	?ReceiveSendEventToClientEvent@RMMFDevSoundProxy@@QAEXAAV?$TPckgBuf@VTMMFEvent@@@@AAVTRequestStatus@@@Z @ 60 NONAME ; public: void __thiscall RMMFDevSoundProxy::ReceiveSendEventToClientEvent(class TPckgBuf<class TMMFEvent> &,class TRequestStatus &)
	?CancelRegisterAsClient@RMMFDevSoundProxy@@QAEHVTUid@@@Z @ 61 NONAME ; int RMMFDevSoundProxy::CancelRegisterAsClient(class TUid)
	?GetResourceNotificationData@RMMFDevSoundProxy@@QAEHVTUid@@AAVTDes8@@@Z @ 62 NONAME ; int RMMFDevSoundProxy::GetResourceNotificationData(class TUid, class TDes8 &)
	?RegisterAsClient@RMMFDevSoundProxy@@QAEHVTUid@@ABVTDesC8@@@Z @ 63 NONAME ; int RMMFDevSoundProxy::RegisterAsClient(class TUid, class TDesC8 const &)
	?WillResumePlay@RMMFDevSoundProxy@@QAEHXZ @ 64 NONAME ; int RMMFDevSoundProxy::WillResumePlay(void)
	?SetClientThreadInfo@RMMFDevSoundProxy@@QAEHAAVTThreadId@@@Z @ 65 NONAME ; int RMMFDevSoundProxy::SetClientThreadInfo(class TThreadId &)

